# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class TextArea(Component):
    """A TextArea component.
Use the <TextArea> React component, which can be controlled similar to an <InputGroup> element.

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- addOnBlur (boolean; optional):
    If True, onAdd will be invoked when the input loses focus.
    Otherwise, onAdd  is only invoked when enter is pressed.

- autoResize (boolean; optional):
    Whether the component should automatically resize vertically as a
    user types in the text input.  This will disable manual resizing
    in the vertical dimension.

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- disabled (boolean; optional):
    Whether the input is non-interactive.

- fill (boolean; optional):
    Whether the component should take up the full width of its
    container.

- intent (string; optional):
    Visual intent color to apply to element.

- large (boolean; optional):
    If set to True, the input will display with larger styling. This
    is equivalent to setting  Classes.LARGE via className on the
    parent control group and on the child input group.

- placeholder (string; optional):
    Placeholder text when there is no value.

- readOnly (boolean; optional):
    Disable the user interaction without applying the disabled style.

- small (boolean; optional):
    Whether the file input should appear with small styling.

- style (dict; optional):
    CSS properties to apply to the root element.

- text (string; optional):
    Input text updated when input loses blur or on 'Enter' key press.

- value (string; optional):
    Input value that changes every time a new character is inserted."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_blueprint_components'
    _type = 'TextArea'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, addOnBlur=Component.UNDEFINED, autoResize=Component.UNDEFINED, className=Component.UNDEFINED, disabled=Component.UNDEFINED, fill=Component.UNDEFINED, intent=Component.UNDEFINED, large=Component.UNDEFINED, placeholder=Component.UNDEFINED, readOnly=Component.UNDEFINED, small=Component.UNDEFINED, style=Component.UNDEFINED, value=Component.UNDEFINED, text=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'addOnBlur', 'autoResize', 'className', 'disabled', 'fill', 'intent', 'large', 'placeholder', 'readOnly', 'small', 'style', 'text', 'value']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'addOnBlur', 'autoResize', 'className', 'disabled', 'fill', 'intent', 'large', 'placeholder', 'readOnly', 'small', 'style', 'text', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(TextArea, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Tag(Component):
    """A Tag component.
Tags are great for lists of strings.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Content of the Tag.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- active (boolean; optional):
    Whether the tag should appear in an active state.

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- fill (boolean; optional):
    Whether the tag should take up the full width of its container.

- htmlTitle (string; optional):
    HTML title to be passed to the component.

- icon (string; optional):
    Name of a Blueprint UI icon (or an icon element) to render before
    the children.

- intent (string; optional):
    Visual intent color to apply to element.

- interactive (boolean; optional):
    Whether the tag should visually respond to user interactions. If
    set to True,  hovering over the tag will change its color and
    mouse cursor.

- large (boolean; optional):
    Whether this tag should use large styles.

- minimal (boolean; optional):
    Whether this tag should use minimal styles.

- multiline (boolean; optional):
    Whether tag content should be allowed to occupy multiple lines. If
    False, a  single line of text will be truncated with an ellipsis
    if it overflows.  Note that icons will be vertically centered
    relative to multiline text.

- n_clicks (number; optional):
    An integer that represents the time (in ms since 1970) at which
    n_clicks changed. This can be used to tell which button was
    changed most recently. Recommended when interactive is True.

- n_clicks_remove (number; optional):
    An integer that represents the time (in ms since 1970) at which
    the remove button has been clicked. This can be used to tell which
    button was changed most recently.

- removable (boolean; default False):
    Wheter the tag should have a button to handle the removal of the
    tag. To be used with n_clicks_remove.

- rightIcon (string; optional):
    Name of a Blueprint UI icon (or an icon element) to render after
    the children.

- round (boolean; optional):
    Whether this tag should have rounded ends.

- style (dict; optional):
    CSS properties to apply to the root element."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_blueprint_components'
    _type = 'Tag'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, active=Component.UNDEFINED, className=Component.UNDEFINED, fill=Component.UNDEFINED, htmlTitle=Component.UNDEFINED, icon=Component.UNDEFINED, intent=Component.UNDEFINED, interactive=Component.UNDEFINED, large=Component.UNDEFINED, minimal=Component.UNDEFINED, multiline=Component.UNDEFINED, n_clicks=Component.UNDEFINED, n_clicks_remove=Component.UNDEFINED, removable=Component.UNDEFINED, rightIcon=Component.UNDEFINED, round=Component.UNDEFINED, style=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'active', 'className', 'fill', 'htmlTitle', 'icon', 'intent', 'interactive', 'large', 'minimal', 'multiline', 'n_clicks', 'n_clicks_remove', 'removable', 'rightIcon', 'round', 'style']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'active', 'className', 'fill', 'htmlTitle', 'icon', 'intent', 'interactive', 'large', 'minimal', 'multiline', 'n_clicks', 'n_clicks_remove', 'removable', 'rightIcon', 'round', 'style']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(Tag, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Radio(Component):
    """A Radio component.
A radio button typically represents a single option in a mutually exclusive list

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    JSX label for the control.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- alignIndicator (string; optional):
    Alignment of the indicator within container.

- checked (boolean; optional):
    Whether the control is checked.

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- defaultChecked (boolean; optional):
    Whether the control is initially checked (uncontrolled mode).

- disabled (boolean; optional):
    Whether the control is non-interactive.

- inline (boolean; optional):
    Whether the control should appear as an inline element.

- label (string; optional):
    Use children or labelElement to supply JSX content. This prop
    actually  supports JSX elements, but TypeScript will throw an
    error because  HTMLAttributes only allows strings.

- labelElement (a list of or a singular dash component, string or number; optional):
    JSX Element label for the control. This prop is a workaround for
    TypeScript  consumers as the type definition for label only
    accepts strings.  JavaScript consumers can provide a JSX element
    directly to label.

- large (boolean; optional):
    Whether this control should use large styles.

- style (dict; optional):
    CSS properties to apply to the root element.

- tagName (string; optional):
    Name of the HTML tag that wraps the checkbox. By default a <label>
    is used,  which effectively enlarges the click target to include
    all of its children.  Supply a different tag name if this behavior
    is undesirable or you're listening  to click events from a parent
    element (as the label can register duplicate clicks).

- value (string; optional):
    Value of the radio."""
    _children_props = ['labelElement']
    _base_nodes = ['labelElement', 'children']
    _namespace = 'dash_blueprint_components'
    _type = 'Radio'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, alignIndicator=Component.UNDEFINED, checked=Component.UNDEFINED, className=Component.UNDEFINED, defaultChecked=Component.UNDEFINED, disabled=Component.UNDEFINED, inline=Component.UNDEFINED, label=Component.UNDEFINED, labelElement=Component.UNDEFINED, large=Component.UNDEFINED, style=Component.UNDEFINED, tagName=Component.UNDEFINED, value=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'alignIndicator', 'checked', 'className', 'defaultChecked', 'disabled', 'inline', 'label', 'labelElement', 'large', 'style', 'tagName', 'value']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'alignIndicator', 'checked', 'className', 'defaultChecked', 'disabled', 'inline', 'label', 'labelElement', 'large', 'style', 'tagName', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(Radio, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Tree(Component):
    """A Tree component.
Trees display hierarchical data.

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- clicked_node (list; optional):
    Array of numbers representing a node's position in the tree when
    clicked.

- collapsed_node (list; optional):
    Array of numbers representing a node's position in the tree when
    collapsed.

- contents (list; required):
    The data specifying the contents and appearance of the tree.

- current_contents (list; optional):
    Tree content updated after user interaction.

- expanded_node (list; optional):
    Array of numbers representing a node's position in the tree when
    expanded.

- style (dict; optional):
    CSS properties to apply to the root element."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_blueprint_components'
    _type = 'Tree'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, className=Component.UNDEFINED, contents=Component.REQUIRED, clicked_node=Component.UNDEFINED, collapsed_node=Component.UNDEFINED, expanded_node=Component.UNDEFINED, current_contents=Component.UNDEFINED, style=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'className', 'clicked_node', 'collapsed_node', 'contents', 'current_contents', 'expanded_node', 'style']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'className', 'clicked_node', 'collapsed_node', 'contents', 'current_contents', 'expanded_node', 'style']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        for k in ['contents']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')

        super(Tree, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Omnibar(Component):
    """An Omnibar component.
Omnibar is a macOS Spotlight-style typeahead component composing Overlay and QueryList

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- initialContent (a list of or a singular dash component, string or number; optional):
    React content to render when query is empty. If omitted, all items
    will be rendered (or result of itemListPredicate with empty
    query).  If explicit None, nothing will be rendered when query is
    empty.

- isOpen (boolean; optional):
    Toggles the visibility of the omnibar.

- items (list; optional):
    Array of items in the list.

- matchTargetWidth (boolean; optional):
    Set the popover width equal to the target width.

- minimal (boolean; optional):
    Apply minimal style to popover.

- overlayHasBackdrop (boolean; optional):
    Whether a container-spanning backdrop element should be rendered
    behind the contents.

- resetOnQuery (boolean; optional):
    Whether the active item should be reset to the first matching item
    every time the query changes (via prop or by user input).

- resetOnSelect (boolean; optional):
    Whether the active item should be reset to the first matching item
    when an item is selected. The query will also be reset to the
    empty string.

- selectedItem (dict; optional):
    Selected item.

- style (dict; optional):
    CSS properties to apply to the root element."""
    _children_props = ['initialContent']
    _base_nodes = ['initialContent', 'children']
    _namespace = 'dash_blueprint_components'
    _type = 'Omnibar'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, className=Component.UNDEFINED, overlayHasBackdrop=Component.UNDEFINED, initialContent=Component.UNDEFINED, isOpen=Component.UNDEFINED, items=Component.UNDEFINED, matchTargetWidth=Component.UNDEFINED, minimal=Component.UNDEFINED, selectedItem=Component.UNDEFINED, style=Component.UNDEFINED, resetOnQuery=Component.UNDEFINED, resetOnSelect=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'className', 'initialContent', 'isOpen', 'items', 'matchTargetWidth', 'minimal', 'overlayHasBackdrop', 'resetOnQuery', 'resetOnSelect', 'selectedItem', 'style']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'className', 'initialContent', 'isOpen', 'items', 'matchTargetWidth', 'minimal', 'overlayHasBackdrop', 'resetOnQuery', 'resetOnSelect', 'selectedItem', 'style']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(Omnibar, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class OverlayToaster(Component):
    """An OverlayToaster component.
The OverlayToaster component (previously named Toaster) is a stateful container for a single list of toasts.

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- autoFocus (boolean; optional):
    Whether a toast should acquire application focus when it first
    opens. This is disabled by default so  that toasts do not
    interrupt the user's flow. Note that enforceFocus is always
    disabled for Toasters.

- canEscapeKeyClear (boolean; optional):
    Whether pressing the esc key should clear all active toasts.

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- maxToasts (number; optional):
    Toasts to be displayed.

- position (string; optional):
    Position of Toaster within its container.

- style (dict; optional):
    CSS properties to apply to the root element.

- toasts (list; optional):
    The maximum number of active toasts that can be displayed at once.
    When the limit is  about to be exceeded, the oldest active toast
    is removed.

- usePortal (boolean; optional):
    Whether the toaster should be rendered into a new element attached
    to document.body. If False,  then positioning will be relative to
    the parent element."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_blueprint_components'
    _type = 'OverlayToaster'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, autoFocus=Component.UNDEFINED, className=Component.UNDEFINED, canEscapeKeyClear=Component.UNDEFINED, toasts=Component.UNDEFINED, maxToasts=Component.UNDEFINED, position=Component.UNDEFINED, usePortal=Component.UNDEFINED, style=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'autoFocus', 'canEscapeKeyClear', 'className', 'maxToasts', 'position', 'style', 'toasts', 'usePortal']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'autoFocus', 'canEscapeKeyClear', 'className', 'maxToasts', 'position', 'style', 'toasts', 'usePortal']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(OverlayToaster, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class ButtonGroup(Component):
    """A ButtonGroup component.
Button groups arrange multiple buttons in a horizontal or vertical group.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Buttons in this group.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- alignText (a value equal to: 'left', 'right', 'center'; optional):
    Text alignment within button. By default, icons and text  will be
    centered within the button. Passing \"left\" or \"right\"  will
    align the button text to that side and push icon and  rightIcon to
    either edge. Passing \"center\" will center the  text and icons
    together.

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- fill (boolean; optional):
    Whether the button group should take up the full width of its
    container.

- large (boolean; optional):
    Whether this button should use large styles.

- minimal (boolean; optional):
    Whether this button should use minimal styles.

- style (dict; optional):
    CSS properties to apply to the root element.

- vertical (boolean; optional):
    Whether the button group should appear with vertical styling."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_blueprint_components'
    _type = 'ButtonGroup'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, alignText=Component.UNDEFINED, className=Component.UNDEFINED, fill=Component.UNDEFINED, large=Component.UNDEFINED, minimal=Component.UNDEFINED, vertical=Component.UNDEFINED, style=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'alignText', 'className', 'fill', 'large', 'minimal', 'style', 'vertical']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'alignText', 'className', 'fill', 'large', 'minimal', 'style', 'vertical']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(ButtonGroup, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Tabs(Component):
    """A Tabs component.
Tabs is the top-level component responsible for rendering the tab list and coordinating selection.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Tab elements.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- animate (boolean; optional):
    Whether the selected tab indicator should animate its movement.

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- defaultSelectedTabId (string; optional):
    Initial selected tab id, for uncontrolled usage. Note that this
    prop refers  only to <Tab> children; other types of elements are
    ignored.

- fill (boolean; optional):
    Whether to make the tabs list fill the height of its parent. This
    has no effect when vertical={True}. This is not recommended when
    tab panels  are defined within this component subtree, as the
    height computation will include  the panel height, which is
    usually not intended. Instead, it works well if the  panels are
    rendered elsewhere in the React tree.

- large (boolean; optional):
    If set to True, the tab titles will display with larger styling.
    This will apply  large styles only to the tabs at this level, not
    to nested tabs.

- renderActiveTabPanelOnly (boolean; optional):
    Whether inactive tab panels should be removed from the DOM and
    unmounted in React.  This can be a performance enhancement when
    rendering many complex panels, but requires  careful support for
    unmounting and remounting.

- selectedTabId (string; optional):
    Selected tab id, for controlled usage. Providing this prop will
    put the component  in controlled mode. Unknown ids will result in
    empty selection (no errors).

- vertical (boolean; optional):
    Whether to show tabs stacked vertically on the left side."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_blueprint_components'
    _type = 'Tabs'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, animate=Component.UNDEFINED, className=Component.UNDEFINED, defaultSelectedTabId=Component.UNDEFINED, fill=Component.UNDEFINED, large=Component.UNDEFINED, renderActiveTabPanelOnly=Component.UNDEFINED, selectedTabId=Component.UNDEFINED, vertical=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'animate', 'className', 'defaultSelectedTabId', 'fill', 'large', 'renderActiveTabPanelOnly', 'selectedTabId', 'vertical']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'animate', 'className', 'defaultSelectedTabId', 'fill', 'large', 'renderActiveTabPanelOnly', 'selectedTabId', 'vertical']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(Tabs, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Tab(Component):
    """A Tab component.
Tab is a minimal wrapper with no functionality of its own—it is managed entirely by its parent Tabs wrapper.

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- disabled (boolean; optional):
    Whether the tab is disabled.

- icon (string; optional):
    Name of a Blueprint UI icon to render before the children.

- panel (a list of or a singular dash component, string or number; optional):
    Panel content, rendered by the parent Tabs when this tab is
    active. If omitted,  no panel will be rendered for this tab.

- panelClassName (string; optional):
    Space-delimited string of class names applied to tab panel
    container.

- title (a list of or a singular dash component, string or number; optional):
    Content of tab title, rendered in a list above the active panel."""
    _children_props = ['panel', 'title']
    _base_nodes = ['panel', 'title', 'children']
    _namespace = 'dash_blueprint_components'
    _type = 'Tab'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, className=Component.UNDEFINED, disabled=Component.UNDEFINED, icon=Component.UNDEFINED, panel=Component.UNDEFINED, panelClassName=Component.UNDEFINED, title=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'className', 'disabled', 'icon', 'panel', 'panelClassName', 'title']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'className', 'disabled', 'icon', 'panel', 'panelClassName', 'title']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(Tab, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class ProgressBar(Component):
    """A ProgressBar component.
Progress bars indicate progress towards the completion of a task or an indeterminate loading state.

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- animate (boolean; optional):
    Whether the background should animate.

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- intent (string; optional):
    Visual intent color to apply to element.

- stripes (boolean; optional):
    Whether the background should be striped.

- style (dict; optional):
    CSS properties to apply to the root element.

- value (number; optional):
    A value between 0 and 1 (inclusive) representing how far along the
    operation is. Values below 0 or above 1 will be interpreted as 0
    or 1,  respectively. Omitting this prop will result in an
    \"indeterminate\"  progress meter that fills the entire bar."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_blueprint_components'
    _type = 'ProgressBar'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, animate=Component.UNDEFINED, className=Component.UNDEFINED, intent=Component.UNDEFINED, stripes=Component.UNDEFINED, value=Component.UNDEFINED, style=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'animate', 'className', 'intent', 'stripes', 'style', 'value']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'animate', 'className', 'intent', 'stripes', 'style', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(ProgressBar, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class TagInput(Component):
    """A TagInput component.
Tag inputs render Tags inside an input, followed by an actual text input. 
The container is styled to look like a Blueprint input; the actual editable element appears 
after the last tag. Clicking anywhere on the container will focus the text input.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Optional child elements which will be rendered between the
    selected tags and the text input.  Rendering children is usually
    unnecessary.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- addOnBlur (boolean; optional):
    If True, onAdd will be invoked when the input loses focus.
    Otherwise,  onAdd is only invoked when enter is pressed.

- addOnPaste (boolean; optional):
    If True, onAdd will be invoked when the user pastes text
    containing the separator  into the input. Otherwise, pasted text
    will remain in the input.      Note: For example, if
    addOnPaste=True and separator=\"\n\" (new line), then:       -
    Pasting \"hello\" will not invoke onAdd       - Pasting
    \"hello\n\" will invoke onAdd with [\"hello\"]       - Pasting
    \"hello\nworld\" will invoke onAdd with [\"hello\", \"world\"].

- autoResize (boolean; optional):
    Whether the component should automatically resize as a user types
    in the text input.  This will have no effect when fill={True}.

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- disabled (boolean; optional):
    Whether the input is non-interactive.

- fill (boolean; optional):
    Whether the component should take up the full width of its
    container.

- intent (string; optional):
    Visual intent color to apply to element.

- large (boolean; optional):
    If set to True, the input will display with larger styling. This
    is equivalent to setting  Classes.LARGE via className on the
    parent control group and on the child input group.

- leftIcon (string; optional):
    Name of a Blueprint UI icon to render on the left side of the
    input group, before the user's cursor.

- placeholder (string; optional):
    Placeholder text in the absence of any value.

- separator (boolean; optional):
    Whether to split input text into multiple values. Default value
    splits on commas and newlines. Explicit False value disables
    splitting.

- style (dict; optional):
    CSS properties to apply to the root element.

- tagAdded (list; optional):
    Value updated when a new tag is added. Object with value and index
    of the tag.

- tagIntents (boolean; default False):
    cycle tag intent.

- tagLarge (boolean; default False):
    Apply large style to tags.

- tagMinimal (boolean; default False):
    Apply minimal style to tags.

- tagRemoved (dict; optional):
    Value updated when a tag is removed. Object with value and index
    of the tag.

- values (a list of or a singular dash component, string or number; optional):
    Controlled tag values. Each value will be rendered inside a Tag."""
    _children_props = ['values']
    _base_nodes = ['values', 'children']
    _namespace = 'dash_blueprint_components'
    _type = 'TagInput'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, addOnBlur=Component.UNDEFINED, addOnPaste=Component.UNDEFINED, autoResize=Component.UNDEFINED, className=Component.UNDEFINED, tagIntents=Component.UNDEFINED, disabled=Component.UNDEFINED, fill=Component.UNDEFINED, intent=Component.UNDEFINED, large=Component.UNDEFINED, leftIcon=Component.UNDEFINED, placeholder=Component.UNDEFINED, separator=Component.UNDEFINED, style=Component.UNDEFINED, tagAdded=Component.UNDEFINED, tagRemoved=Component.UNDEFINED, tagLarge=Component.UNDEFINED, tagMinimal=Component.UNDEFINED, values=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'addOnBlur', 'addOnPaste', 'autoResize', 'className', 'disabled', 'fill', 'intent', 'large', 'leftIcon', 'placeholder', 'separator', 'style', 'tagAdded', 'tagIntents', 'tagLarge', 'tagMinimal', 'tagRemoved', 'values']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'addOnBlur', 'addOnPaste', 'autoResize', 'className', 'disabled', 'fill', 'intent', 'large', 'leftIcon', 'placeholder', 'separator', 'style', 'tagAdded', 'tagIntents', 'tagLarge', 'tagMinimal', 'tagRemoved', 'values']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(TagInput, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class DialogStep(Component):
    """A DialogStep component.
Step of a MultistepDialog component

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- panel (a list of or a singular dash component, string or number; optional):
    Panel content, rendered by the parent MultistepDialog when this
    step is active.

- portalClassName (string; optional):
    Space-delimited string of class names applied to the Portal
    element if usePortal={True}.

- style (dict; optional):
    CSS properties to apply to the root element.

- title (a list of or a singular dash component, string or number; optional):
    Title of the dialog. If provided, an element with
    Classes.DIALOG_HEADER will be rendered inside the dialog before
    any children elements."""
    _children_props = ['panel', 'title']
    _base_nodes = ['panel', 'title', 'children']
    _namespace = 'dash_blueprint_components'
    _type = 'DialogStep'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, className=Component.UNDEFINED, panel=Component.UNDEFINED, portalClassName=Component.UNDEFINED, style=Component.UNDEFINED, title=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'className', 'panel', 'portalClassName', 'style', 'title']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'className', 'panel', 'portalClassName', 'style', 'title']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(DialogStep, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class RadioGroup(Component):
    """A RadioGroup component.
A radio button typically represents a single option in a mutually exclusive list (where only one item can be selected at a time).

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    A space-delimited list of class names to pass along to a child
    element.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- asCard (boolean; optional):
    Whether to render the radio as RadioCard.

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- disabled (boolean; optional):
    Whether the group and all its radios are disabled. Individual
    radios  can be disabled using their disabled prop.

- inline (boolean; optional):
    Whether the radio buttons are to be displayed inline horizontally.

- label (string; optional):
    Optional label text to display above the radio buttons.

- name (string; optional):
    Name of the group, used to link radio buttons together in HTML. If
    omitted, a  unique name will be generated internally.

- options (list; optional):
    Array of options to render in the group.

- selectedValue (string | number; optional):
    Value of the selected radio. The child with this value will be
    :checked.

- style (dict; optional):
    CSS properties to apply to the root element."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_blueprint_components'
    _type = 'RadioGroup'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, asCard=Component.UNDEFINED, className=Component.UNDEFINED, disabled=Component.UNDEFINED, inline=Component.UNDEFINED, label=Component.UNDEFINED, name=Component.UNDEFINED, options=Component.UNDEFINED, selectedValue=Component.UNDEFINED, style=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'asCard', 'className', 'disabled', 'inline', 'label', 'name', 'options', 'selectedValue', 'style']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'asCard', 'className', 'disabled', 'inline', 'label', 'name', 'options', 'selectedValue', 'style']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(RadioGroup, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Toast(Component):
    """A Toast component.
A toast is a lightweight, ephemeral notice from an application in direct response to a user's action.

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- icon (string; optional):
    Name of a Blueprint UI icon to display on the left side.

- intent (string; optional):
    Visual intent color to apply to element.

- isCloseButtonShown (boolean; optional):
    Whether to show the close button in the dialog's header. Note that
    the header will only be  rendered if title is provided.

- message (a list of or a singular dash component, string or number; optional):
    Message to display in the body of the toast.

- style (dict; optional):
    CSS properties to apply to the root element.

- timeout (number; optional):
    Milliseconds to wait before automatically dismissing toast.
    Providing a value less than or equal  to 0 will disable the
    timeout (this is discouraged)."""
    _children_props = ['message']
    _base_nodes = ['message', 'children']
    _namespace = 'dash_blueprint_components'
    _type = 'Toast'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, className=Component.UNDEFINED, icon=Component.UNDEFINED, intent=Component.UNDEFINED, isCloseButtonShown=Component.UNDEFINED, message=Component.UNDEFINED, timeout=Component.UNDEFINED, style=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'className', 'icon', 'intent', 'isCloseButtonShown', 'message', 'style', 'timeout']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'className', 'icon', 'intent', 'isCloseButtonShown', 'message', 'style', 'timeout']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(Toast, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class MultiSlider(Component):
    """A MultiSlider component.
MultiSlider is a flexible solution for picking arbitrary values on a number line.

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- defaultTrackIntent (string; optional):
    Default intent of a track segment, used only if no handle
    specifies intentBefore/After.

- disabled (boolean; optional):
    Whether the slider is non-interactive.

- format (boolean | string | dict; optional):
    This props is limitated with respect the react implementation.  It
    manage the formatting of the label, in the following way: -
    True/False controls the display of the label. - 'percentage': it
    displays the number in percentage format. - {'before': value,
    'after': value}: it adds the value before and after   the label.

- handles (list; optional):
    List of handles. This prop is updated everytime the value of a
    handle changes. It can be used to retrive the current value of
    handles.

- intent (string; optional):
    Visual intent color to apply to element.

- labelPrecision (number; optional):
    Number of decimal places to use when rendering label value.
    Default  value is the number of decimals used in the stepSize
    prop.  This prop has no effect if you supply a custom
    labelRenderer callback.

- labelStepSize (number; optional):
    Increment between successive labels. Must be greater than zero.

- labelValues (list; optional):
    Array of specific values for the label placement. This prop is
    mutually exclusive with labelStepSize.

- max (number; optional):
    Maximum value of the slider.

- min (number; optional):
    Minimum value of the slider.

- n_changes (number; default 0):
    An integer that represents the time (in ms since 1970) at which
    n_clicks changed. This can be used to detected when the value on
    the slider changes.

- n_releases (number; default 0):
    An integer that represents the time (in ms since 1970) at which
    n_releases changed. This can be used to detected when the handle
    is releases.

- showTrackFill (boolean; optional):
    Whether a solid bar should be rendered on the track between
    current and  initial values, or between handles for RangeSlider.

- stepSize (number; optional):
    Increment between successive values; amount by which the handle
    moves. Must be greater than zero.

- style (dict; optional):
    CSS properties to apply to the root element.

- vertical (boolean; optional):
    Whether to show the slider in a vertical orientation."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_blueprint_components'
    _type = 'MultiSlider'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, className=Component.UNDEFINED, defaultTrackIntent=Component.UNDEFINED, disabled=Component.UNDEFINED, intent=Component.UNDEFINED, handles=Component.UNDEFINED, labelPrecision=Component.UNDEFINED, format=Component.UNDEFINED, labelStepSize=Component.UNDEFINED, labelValues=Component.UNDEFINED, max=Component.UNDEFINED, min=Component.UNDEFINED, n_changes=Component.UNDEFINED, n_releases=Component.UNDEFINED, showTrackFill=Component.UNDEFINED, stepSize=Component.UNDEFINED, style=Component.UNDEFINED, vertical=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'className', 'defaultTrackIntent', 'disabled', 'format', 'handles', 'intent', 'labelPrecision', 'labelStepSize', 'labelValues', 'max', 'min', 'n_changes', 'n_releases', 'showTrackFill', 'stepSize', 'style', 'vertical']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'className', 'defaultTrackIntent', 'disabled', 'format', 'handles', 'intent', 'labelPrecision', 'labelStepSize', 'labelValues', 'max', 'min', 'n_changes', 'n_releases', 'showTrackFill', 'stepSize', 'style', 'vertical']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(MultiSlider, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Button(Component):
    """A Button component.
Buttons trigger actions when clicked. Button and AnchorButton components generate different HTML tags.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Button contents.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- active (boolean; optional):
    If set to True, the button will display in an active state.  This
    is equivalent to setting className={Classes.ACTIVE}.

- alignText (a value equal to: 'left', 'right', 'center'; optional):
    Text alignment within button. By default, icons and text  will be
    centered within the button. Passing \"left\" or \"right\"  will
    align the button text to that side and push icon and  rightIcon to
    either edge. Passing \"center\" will center the  text and icons
    together.

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- disabled (boolean; optional):
    Whether this action is non-interactive.

- fill (boolean; optional):
    Whether this button should expand to fill its container.

- href (string; optional):
    Link URL.

- icon (a list of or a singular dash component, string or number; optional):
    Name of a Blueprint UI icon (or an icon element) to render  before
    the text.

- intent (string; optional):
    Visual intent color to apply to element.

- large (boolean; optional):
    Whether this button should use large styles.

- loading (boolean; optional):
    If set to True, the button will display a centered loading
    spinner instead of its contents and the button will be  disabled
    (even if disabled={False}). The width of the button  is not
    affected by the value of this prop.

- minimal (boolean; optional):
    Whether this button should use minimal styles.

- n_clicks (number; default 0):
    An integer that represents the time (in ms since 1970) at which
    n_clicks changed. This can be used to tell which button was
    changed most recently.

- outlined (boolean; optional):
    Whether this button should use outlined styles.

- rightIcon (a list of or a singular dash component, string or number; optional):
    Name of a Blueprint UI icon (or an icon element) to render after
    the text.

- small (boolean; optional):
    Whether this button should use small styles.

- style (dict; optional):
    CSS styles to apply to the button.

- target (string; optional):
    Target.

- text (a list of or a singular dash component, string or number; optional):
    Action text. Can be any single React renderable.

- type (a value equal to: 'submit', 'reset', 'button'; default 'button'):
    HTML type attribute of button. Accepted values are \"button\",
    \"submit\", and \"reset\". Note that this prop has no effect  on
    AnchorButton; it only affects Button."""
    _children_props = ['icon', 'rightIcon', 'text']
    _base_nodes = ['icon', 'rightIcon', 'text', 'children']
    _namespace = 'dash_blueprint_components'
    _type = 'Button'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, active=Component.UNDEFINED, alignText=Component.UNDEFINED, className=Component.UNDEFINED, disabled=Component.UNDEFINED, fill=Component.UNDEFINED, icon=Component.UNDEFINED, intent=Component.UNDEFINED, large=Component.UNDEFINED, loading=Component.UNDEFINED, minimal=Component.UNDEFINED, n_clicks=Component.UNDEFINED, href=Component.UNDEFINED, outlined=Component.UNDEFINED, rightIcon=Component.UNDEFINED, small=Component.UNDEFINED, text=Component.UNDEFINED, type=Component.UNDEFINED, target=Component.UNDEFINED, style=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'active', 'alignText', 'className', 'disabled', 'fill', 'href', 'icon', 'intent', 'large', 'loading', 'minimal', 'n_clicks', 'outlined', 'rightIcon', 'small', 'style', 'target', 'text', 'type']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'active', 'alignText', 'className', 'disabled', 'fill', 'href', 'icon', 'intent', 'large', 'loading', 'minimal', 'n_clicks', 'outlined', 'rightIcon', 'small', 'style', 'target', 'text', 'type']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(Button, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Select(Component):
    """A Select component.
The Select component renders a UI to choose one item from a list.

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- disabled (boolean; optional):
    Whether the component is non-interactive. If True, the list's item
    renderer will not be called. Note that you'll  also need to
    disable the component's children, if appropriate.

- fill (boolean; optional):
    Whether the wrapper and target should take up the full width of
    their container. Note that supplying True for this  prop will
    force targetTagName=\"div\".

- filterable (boolean; optional):
    Whether the dropdown list can be filtered.

- initialContent (a list of or a singular dash component, string or number; optional):
    React content to render when query is empty. If omitted, all items
    will be rendered (or result of itemListPredicate with empty
    query).  If explicit None, nothing will be rendered when query is
    empty.

- items (list; optional):
    Array of items in the list.

- matchTargetWidth (boolean; optional):
    Set the popover width equal to the target width.

- minimal (boolean; optional):
    Apply minimal style to popover.

- resetOnClose (boolean; optional):
    Whether the active item should be reset to the first matching item
    when the popover closes. The query will also be reset to the empty
    string.

- resetOnQuery (boolean; optional):
    Whether the active item should be reset to the first matching item
    every time the query changes (via prop or by user input).

- resetOnSelect (boolean; optional):
    Whether the active item should be reset to the first matching item
    when an item is selected. The query will also be reset to the
    empty string.

- selectedItem (dict; optional):
    Selected item.

- style (dict; optional):
    CSS properties to apply to the root element."""
    _children_props = ['initialContent']
    _base_nodes = ['initialContent', 'children']
    _namespace = 'dash_blueprint_components'
    _type = 'Select'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, className=Component.UNDEFINED, disabled=Component.UNDEFINED, fill=Component.UNDEFINED, filterable=Component.UNDEFINED, initialContent=Component.UNDEFINED, items=Component.UNDEFINED, matchTargetWidth=Component.UNDEFINED, minimal=Component.UNDEFINED, selectedItem=Component.UNDEFINED, style=Component.UNDEFINED, resetOnClose=Component.UNDEFINED, resetOnQuery=Component.UNDEFINED, resetOnSelect=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'className', 'disabled', 'fill', 'filterable', 'initialContent', 'items', 'matchTargetWidth', 'minimal', 'resetOnClose', 'resetOnQuery', 'resetOnSelect', 'selectedItem', 'style']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'className', 'disabled', 'fill', 'filterable', 'initialContent', 'items', 'matchTargetWidth', 'minimal', 'resetOnClose', 'resetOnQuery', 'resetOnSelect', 'selectedItem', 'style']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(Select, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Popover(Component):
    """A Popover component.
Popovers display floating content next to a target element.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Interactive element which will trigger the popover.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- autoFocus (boolean; optional):
    Whether the popover/tooltip should acquire application focus when
    it first opens.

- boundary (string; optional):
    CSS class names to apply to backdrop element. One of
    \"scrollParent\" \"body\" \"clippingParents\".

- canEscapeKeyClose (boolean; optional):
    Whether pressing the esc key should invoke onClose.

- captureDismiss (boolean; optional):
    When enabled, clicks inside a Classes.POPOVER_DISMISS element will
    only close the current popover and not outer  popovers. When
    disabled, the current popover and any ancestor popovers will be
    closed.  See:
    http://blueprintjs.com/docs/#core/components/popover.closing-on-click.

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- content (a list of or a singular dash component, string or number; optional):
    The content displayed inside the popover.

- defaultIsOpen (boolean; optional):
    Initial opened state when uncontrolled.

- disabled (boolean; optional):
    Prevents the popover from appearing when True.

- enforceFocus (boolean; optional):
    Whether the overlay should prevent focus from leaving itself. That
    is, if the user attempts to focus an element outside  the overlay
    and this prop is enabled, then the overlay will immediately bring
    focus back to itself. If you are nesting  overlay components,
    either disable this prop on the \"outermost\" overlays or mark the
    nested ones usePortal={False}.

- fill (boolean; optional):
    Whether the wrapper and target should take up the full width of
    their container. Note that supplying True for this  prop will
    force targetTagName=\"div\".

- hasBackdrop (boolean; optional):
    Enables an invisible overlay beneath the popover that captures
    clicks and prevents interaction with the rest of the document
    until the popover is closed. This prop is only available when
    interactionKind is PopoverInteractionKind.CLICK.  When popovers
    with backdrop are opened, they become focused.

- hoverCloseDelay (number; optional):
    The amount of time in milliseconds the popover should remain open
    after the user hovers off the trigger. The timer is  canceled if
    the user mouses over the target before it expires.

- hoverOpenDelay (number; optional):
    The amount of time in milliseconds the popover should wait before
    opening after the user hovers over the trigger.  The timer is
    canceled if the user mouses away from the target before it
    expires.

- inheritDarkTheme (boolean; optional):
    Whether a popover that uses a Portal should automatically inherit
    the dark theme from its parent.

- interactionKind (string; optional):
    The kind of interaction that triggers the display of the popover.
    Either \"click\", \"click-target\" or \"hover-target\",.

- isOpen (boolean; default False):
    Whether the popover is visible. Passing this prop puts the popover
    in controlled mode, where the only way to change  visibility is by
    updating this property. If disabled={True}, this prop will be
    ignored, and the popover will remain closed.

- lazy (boolean; optional):
    If True and usePortal={True}, the Portal containing the children
    is created and attached to the DOM when the overlay is opened  for
    the first time; otherwise this happens when the component mounts.
    Lazy mounting provides noticeable performance improvements  if you
    have lots of overlays at once, such as on each row of a table.

- matchTargetWidth (boolean; optional):
    Whether the popover content should be sized to match the width of
    the target. This is sometimes useful for dropdown menus.  This
    prop is implemented using a Popper.js custom modifier.

- minimal (boolean; optional):
    Whether to apply minimal styling to this popover or tooltip.
    Minimal popovers do not have an arrow pointing to their target and
    use a subtler animation.

- openOnTargetFocus (string; optional):
    Whether the popover should open when its target is focused. If
    True, target will render with tabindex=\"0\" to make it focusable
    via keyboard navigation. Note that this functionality is only
    enabled for hover interaction popovers/tooltips.

- placement (string; optional):
    The placement (relative to the target) at which the popover should
    appear. Mutually exclusive with position prop. Prefer using this
    over position,  as it more closely aligns with Popper.js
    semantics. The default value of \"auto\" will choose the best
    placement when opened and will allow the  popover to reposition
    itself to remain onscreen as the user scrolls around.

- popoverClassName (string; optional):
    A space-delimited string of class names applied to the popover
    element.

- popupKind (string; optional):
    The kind of popup displayed by the popover. This property is
    ignored if interactionKind is Popover2InteractionKind is
    HOVER_TARGET_ONLY.  This controls the aria-haspopup attribute of
    the target element. The default is \"menu\" (technically,
    aria-haspopup will be set to \"True\",  which is the same as
    \"menu\", for backwards compatibility).

- portalClassName (string; optional):
    Space-delimited string of class names applied to the Portal
    element if usePortal={True}.

- portalContainer (a list of or a singular dash component, string or number; optional):
    The container element into which the overlay renders its contents,
    when usePortal is True. This prop is  ignored if usePortal is
    False.

- position (string; optional):
    The position (relative to the target) at which the popover should
    appear. Mutually exclusive with placement prop. The default value
    of \"auto\" will  choose the best position when opened and will
    allow the popover to reposition itself to remain onscreen as the
    user scrolls around.

- positioningStrategy (string; optional):
    Popper.js positioning strategy. See:
    https://popper.js.org/docs/v2/constructors/#strategy.

- shouldReturnFocusOnClose (boolean; optional):
    Whether the application should return focus to the last active
    element in the document after this popover closes. This is
    automatically set to False if  this is a hover interaction
    popover. If you are attaching a popover and a tooltip to the same
    target, you must take care to either disable this prop for  the
    popover or disable the tooltip's openOnTargetFocus prop.

- style (dict; optional):
    CSS properties to apply to the root element.

- transitionDuration (number; optional):
    Indicates how long (in milliseconds) the overlay's enter/leave
    transition takes. This is used by React CSSTransition to know when
    a transition completes  and must match the duration of the
    animation in CSS. Only set this prop if you override Blueprint's
    default transitions with new transitions of a different length.

- usePortal (boolean; optional):
    Whether the popover should be rendered inside a Portal attached to
    portalContainer prop. Rendering content inside a Portal allows the
    popover content to escape the physical bounds of its parent while
    still being positioned correctly relative to its target.  Using a
    Portal is necessary if any ancestor of the target hides overflow
    or uses very complex positioning. Not using a Portal can result in
    smoother performance when scrolling and allows the popover content
    to inherit CSS styles from surrounding elements,  but it remains
    subject to the overflow bounds of its ancestors."""
    _children_props = ['content', 'portalContainer']
    _base_nodes = ['content', 'portalContainer', 'children']
    _namespace = 'dash_blueprint_components'
    _type = 'Popover'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, autoFocus=Component.UNDEFINED, boundary=Component.UNDEFINED, canEscapeKeyClose=Component.UNDEFINED, captureDismiss=Component.UNDEFINED, className=Component.UNDEFINED, content=Component.UNDEFINED, defaultIsOpen=Component.UNDEFINED, disabled=Component.UNDEFINED, enforceFocus=Component.UNDEFINED, fill=Component.UNDEFINED, hasBackdrop=Component.UNDEFINED, hoverCloseDelay=Component.UNDEFINED, hoverOpenDelay=Component.UNDEFINED, inheritDarkTheme=Component.UNDEFINED, interactionKind=Component.UNDEFINED, isOpen=Component.UNDEFINED, lazy=Component.UNDEFINED, matchTargetWidth=Component.UNDEFINED, minimal=Component.UNDEFINED, openOnTargetFocus=Component.UNDEFINED, placement=Component.UNDEFINED, popoverClassName=Component.UNDEFINED, popupKind=Component.UNDEFINED, portalClassName=Component.UNDEFINED, portalContainer=Component.UNDEFINED, position=Component.UNDEFINED, positioningStrategy=Component.UNDEFINED, shouldReturnFocusOnClose=Component.UNDEFINED, style=Component.UNDEFINED, transitionDuration=Component.UNDEFINED, usePortal=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'autoFocus', 'boundary', 'canEscapeKeyClose', 'captureDismiss', 'className', 'content', 'defaultIsOpen', 'disabled', 'enforceFocus', 'fill', 'hasBackdrop', 'hoverCloseDelay', 'hoverOpenDelay', 'inheritDarkTheme', 'interactionKind', 'isOpen', 'lazy', 'matchTargetWidth', 'minimal', 'openOnTargetFocus', 'placement', 'popoverClassName', 'popupKind', 'portalClassName', 'portalContainer', 'position', 'positioningStrategy', 'shouldReturnFocusOnClose', 'style', 'transitionDuration', 'usePortal']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'autoFocus', 'boundary', 'canEscapeKeyClose', 'captureDismiss', 'className', 'content', 'defaultIsOpen', 'disabled', 'enforceFocus', 'fill', 'hasBackdrop', 'hoverCloseDelay', 'hoverOpenDelay', 'inheritDarkTheme', 'interactionKind', 'isOpen', 'lazy', 'matchTargetWidth', 'minimal', 'openOnTargetFocus', 'placement', 'popoverClassName', 'popupKind', 'portalClassName', 'portalContainer', 'position', 'positioningStrategy', 'shouldReturnFocusOnClose', 'style', 'transitionDuration', 'usePortal']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(Popover, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class RadioCard(Component):
    """A RadioCard component.
Card with an embedded Radio control (left-aligned by default).

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Label for the control as react node element.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- alignIndicator (string; optional):
    Alignment of the indicator within container.

- checked (boolean; optional):
    Whether the control is checked.

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- compact (boolean; optional):
    Whether this component should use compact styles with reduced
    visual padding.

- disabled (boolean; optional):
    Whether the control is non-interactive.

- elevation (number; default 0):
    Controls the intensity of the drop shadow beneath the card: the
    higher  the elevation, the higher the drop shadow. At elevation 0,
    no drop  shadow is applied.

- label (string; optional):
    Text label for the control.

- n_clicks (number; default 0):
    An integer that represents the time (in ms since 1970) at which
    n_clicks changed. This can be used to tell which button was
    changed most recently.

- selected (boolean; optional):
    Whether this card should appear selected.

- showAsSelectedWhenChecked (boolean; optional):
    Whether the component should use \"selected\" Card styling when
    checked.

- style (dict; optional):
    CSS styles to apply to the card.

- value (string; optional):
    value."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_blueprint_components'
    _type = 'RadioCard'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, alignIndicator=Component.UNDEFINED, checked=Component.UNDEFINED, className=Component.UNDEFINED, compact=Component.UNDEFINED, disabled=Component.UNDEFINED, elevation=Component.UNDEFINED, label=Component.UNDEFINED, selected=Component.UNDEFINED, showAsSelectedWhenChecked=Component.UNDEFINED, n_clicks=Component.UNDEFINED, value=Component.UNDEFINED, style=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'alignIndicator', 'checked', 'className', 'compact', 'disabled', 'elevation', 'label', 'n_clicks', 'selected', 'showAsSelectedWhenChecked', 'style', 'value']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'alignIndicator', 'checked', 'className', 'compact', 'disabled', 'elevation', 'label', 'n_clicks', 'selected', 'showAsSelectedWhenChecked', 'style', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(RadioCard, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Tooltip(Component):
    """A Tooltip component.
A tooltip is a lightweight popover for showing additional information during hover interactions.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Interactive element which will trigger the tooltip.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- canEscapeKeyClose (boolean; optional):
    Whether pressing the esc key should invoke onClose.

- captureDismiss (boolean; optional):
    When enabled, clicks inside a Classes.POPOVER_DISMISS element will
    only close the current popover and not outer popovers.  When
    disabled, the current popover and any ancestor popovers will be
    close.

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- compact (boolean; optional):
    Whether to use a compact appearance, which reduces the visual
    padding around tooltip content.

- content (a list of or a singular dash component, string or number; optional):
    The content that will be displayed inside of the tooltip.

- defaultIsOpen (boolean; optional):
    Initial opened state when uncontrolled.

- disabled (boolean; optional):
    Prevents the popover from appearing when True.

- enforceFocus (boolean; optional):
    Whether the overlay should prevent focus from leaving itself. That
    is, if the user attempts to focus an element outside the  overlay
    and this prop is enabled, then the overlay will immediately bring
    focus back to itself.

- fill (boolean; optional):
    Whether the wrapper and target should take up the full width of
    their container. Note that supplying True for this prop will force
    targetTagName=\"div\".

- hoverCloseDelay (number; optional):
    The amount of time in milliseconds the tooltip should remain open
    after the user hovers off the trigger.  The timer is canceled if
    the user mouses over the target before it expires.

- hoverOpenDelay (number; optional):
    The amount of time in milliseconds the tooltip should wait before
    opening after the user hovers over the trigger.  The timer is
    canceled if the user mouses away from the target before it
    expires.

- inheritDarkTheme (boolean; optional):
    Whether a popover that uses a Portal should automatically inherit
    the dark theme from its parent.

- intent (boolean; optional):
    Visual intent color to apply to element.

- interactionKind (string; optional):
    The kind of interaction that triggers the display of the popover.
    Either \"click\", \"click-target\" or \"hover-target\",.

- isOpen (boolean; optional):
    Whether the popover is visible. Passing this prop puts the popover
    in controlled mode, where the only way to change visibility  is by
    updating this property. If disabled={True}, this prop will be
    ignored, and the popover will remain closed.

- matchTargetWidth (boolean; optional):
    Whether the popover content should be sized to match the width of
    the target. This is sometimes useful for dropdown menus.  This
    prop is implemented using a Popper.js custom modifier.

- minimal (boolean; optional):
    Whether to apply minimal styling to this popover or tooltip.
    Minimal popovers do not have an arrow pointing to their  target
    and use a subtler animation.

- openOnTargetFocus (boolean; optional):
    Whether the popover should open when its target is focused. If
    True, target will render with tabindex=\"0\" to make it focusable
    via keyboard navigation.  Note that this functionality is only
    enabled for hover interaction popovers/tooltips.

- placement (string; optional):
    The placement (relative to the target) at which the popover should
    appear. Mutually exclusive with position prop. Prefer using this
    over  position, as it more closely aligns with Popper.js
    semantics. The default value of \"auto\" will choose the best
    placement when opened  and will allow the popover to reposition
    itself to remain onscreen as the user scrolls around.

- popoverClassName (string; optional):
    A space-delimited string of class names applied to the popover
    element.

- position (string; optional):
    The position (relative to the target) at which the popover should
    appear. Mutually exclusive with placement prop. The default value
    of  \"auto\" will choose the best position when opened and will
    allow the popover to reposition itself to remain onscreen as the
    user scrolls  around.

- style (dict; optional):
    CSS properties to apply to the root element.

- transitionDuration (number; optional):
    Indicates how long (in milliseconds) the tooltip's
    appear/disappear transition takes. This is used by React
    CSSTransition  to know when a transition completes and must match
    the duration of the animation in CSS. Only set this prop if you
    override  Blueprint's default transitions with new transitions of
    a different length."""
    _children_props = ['content']
    _base_nodes = ['content', 'children']
    _namespace = 'dash_blueprint_components'
    _type = 'Tooltip'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, canEscapeKeyClose=Component.UNDEFINED, captureDismiss=Component.UNDEFINED, className=Component.UNDEFINED, compact=Component.UNDEFINED, content=Component.UNDEFINED, defaultIsOpen=Component.UNDEFINED, disabled=Component.UNDEFINED, enforceFocus=Component.UNDEFINED, fill=Component.UNDEFINED, hoverCloseDelay=Component.UNDEFINED, hoverOpenDelay=Component.UNDEFINED, inheritDarkTheme=Component.UNDEFINED, intent=Component.UNDEFINED, interactionKind=Component.UNDEFINED, isOpen=Component.UNDEFINED, matchTargetWidth=Component.UNDEFINED, minimal=Component.UNDEFINED, openOnTargetFocus=Component.UNDEFINED, placement=Component.UNDEFINED, popoverClassName=Component.UNDEFINED, position=Component.UNDEFINED, style=Component.UNDEFINED, transitionDuration=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'canEscapeKeyClose', 'captureDismiss', 'className', 'compact', 'content', 'defaultIsOpen', 'disabled', 'enforceFocus', 'fill', 'hoverCloseDelay', 'hoverOpenDelay', 'inheritDarkTheme', 'intent', 'interactionKind', 'isOpen', 'matchTargetWidth', 'minimal', 'openOnTargetFocus', 'placement', 'popoverClassName', 'position', 'style', 'transitionDuration']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'canEscapeKeyClose', 'captureDismiss', 'className', 'compact', 'content', 'defaultIsOpen', 'disabled', 'enforceFocus', 'fill', 'hoverCloseDelay', 'hoverOpenDelay', 'inheritDarkTheme', 'intent', 'interactionKind', 'isOpen', 'matchTargetWidth', 'minimal', 'openOnTargetFocus', 'placement', 'popoverClassName', 'position', 'style', 'transitionDuration']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(Tooltip, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class TimezoneSelect(Component):
    """A TimezoneSelect component.
TimezoneSelect allows the user to select from a list of timezones.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Element which triggers the timezone select popover. If this is
    undefined, by default the component will  render a <Button> which
    shows the currently selected timezone.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- disabled (boolean; optional):
    Whether this component is non-interactive. This prop will be
    ignored if children is provided.

- fill (boolean; optional):
    Whether the component should take up the full width of its
    container. This overrides popoverProps.fill and buttonProps.fill.

- placeholder (string; optional):
    Text to show when no timezone has been selected (value ===
    undefined). This prop will be ignored if children is provided.

- showLocalTimezone (boolean; optional):
    Whether to show the local timezone at the top of the list of
    initial timezone suggestions.

- style (dict; optional):
    CSS properties to apply to the root element.

- value (string; optional):
    The currently selected timezone UTC identifier, e.g.
    \"Pacific/Honolulu\". See: https://www.iana.org/time-zones.

- valueDisplayFormat (string; optional):
    Format to use when displaying the selected (or default) timezone
    within the target element. This prop will be ignored if children
    is provided. Choices: composite, abbreviation, long_name, code,
    offset."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_blueprint_components'
    _type = 'TimezoneSelect'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, className=Component.UNDEFINED, disabled=Component.UNDEFINED, fill=Component.UNDEFINED, placeholder=Component.UNDEFINED, showLocalTimezone=Component.UNDEFINED, style=Component.UNDEFINED, value=Component.UNDEFINED, valueDisplayFormat=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'className', 'disabled', 'fill', 'placeholder', 'showLocalTimezone', 'style', 'value', 'valueDisplayFormat']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'className', 'disabled', 'fill', 'placeholder', 'showLocalTimezone', 'style', 'value', 'valueDisplayFormat']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(TimezoneSelect, self).__init__(children=children, **args)
